@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.4.0;
+package Pcore::WebDriver v0.5.0;
 
 use Pcore -dist, -const, -role, -result,
   -export => {
@@ -250,7 +250,7 @@ sub update_all ( $self, $cb = undef ) {
                             $ENV->share->store( 'bin/webdriver/geckodriver.exe', $temp->path, 'Pcore-WebDriver' );
                         }
                         else {
-                            P->file->untar( $res->body->path, $ENV->share->get_storage( 'bin/', 'Pcore-WebDriver' ) . 'webdriver/geckdriver-linux-x64', strip_component => 0 );
+                            P->file->untar( $res->body->path, $ENV->share->get_storage( 'bin/', 'Pcore-WebDriver' ) . 'webdriver/geckodriver-linux-x64', strip_component => 0 );
                         }
                     };
 
